'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _within = require('./within.js');

var _within2 = _interopRequireDefault(_within);

var _during = require('./during.js');

var _during2 = _interopRequireDefault(_during);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * The difference between within and during
 *
 * within - the expression is true within timeout
 * during - the expression remains true during the delay
 */

exports.default = {
  // visibleWithin the jQuery element is visible within timeout
  visibleWithin: function visibleWithin($) {
    var timeout = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 100;
    return (0, _within2.default)(function () {
      return $.is(':visible');
    }, timeout, 30, 'Was not visibile within ' + timeout + 'ms');
  },
  // hiddenWithin the jQuery element is hidden within timeout
  hiddenWithin: function hiddenWithin($) {
    var timeout = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 100;
    return (0, _within2.default)(function () {
      return !$.is(':visible');
    }, timeout, 30, 'Was not hidden within ' + timeout + 'ms');
  },
  // hiddenDuring the jQuery element remains hidden during the delay
  hiddenDuring: function hiddenDuring($) {
    var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 100;
    return (0, _during2.default)(function () {
      return !$.is(':visible');
    }, delay, 'Did not remain hidden for ' + delay + 'ms');
  },
  // visibleDuring the jQuery element remains hidden during the delay
  visibleDuring: function visibleDuring($) {
    var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 100;
    return (0, _during2.default)(function () {
      return $.is(':visible');
    }, delay, 'Did not remain visible for ' + delay + 'ms');
  }
};